# Changing Theta

Here we show example of ``Theta0`` changing after GADMA run. For more information see `changing_theta.ipynb`

Files here are:

* `YRI_CEU.fs` - Data for two populations YRI, CEU.
* `params` - file with settings for GADMA run.
* `gadma_result` - Already run GADMA results.
* `final_model_moments_code.py` - File with generated code of final model for GADMA run.
